.. py:function:: sf_log_1plusx_mx_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_log_1plusx_mx_e`
    c code signature: int gsl_sf_log_1plusx_mx_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_log_abs_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_log_abs_e`
    c code signature: int gsl_sf_log_abs_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_log_erfc(x [, ret])

    Wrapper for :c:func:`gsl_sf_log_erfc`
    c code signature: double gsl_sf_log_erfc( double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_log_erfc_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_log_erfc_e`
    c code signature: int gsl_sf_log_erfc_e( double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_log_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_log_e`
    c code signature: int gsl_sf_log_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_log_abs(x [, ret])

    Wrapper for :c:func:`gsl_sf_log_abs`
    c code signature: double gsl_sf_log_abs(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_log_1plusx(x [, ret])

    Wrapper for :c:func:`gsl_sf_log_1plusx`
    c code signature: double gsl_sf_log_1plusx(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_log(x [, ret])

    Wrapper for :c:func:`gsl_sf_log`
    c code signature: double gsl_sf_log(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_log_1plusx_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_log_1plusx_e`
    c code signature: int gsl_sf_log_1plusx_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_log_1plusx_mx(x [, ret])

    Wrapper for :c:func:`gsl_sf_log_1plusx_mx`
    c code signature: double gsl_sf_log_1plusx_mx(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

